# aiologger

[![PYPI](https://img.shields.io/pypi/v/aiologger.svg)](http://pypi.python.org/pypi/aiologger)
[![PYPI Python Versions](https://img.shields.io/pypi/pyversions/aiologger.svg)](http://pypi.python.org/pypi/aiologger)
[![Build Status](https://travis-ci.org/b2wdigital/aiologger.svg?branch=master)](https://travis-ci.org/b2wdigital/aiologger)
[![codecov](https://codecov.io/gh/b2wdigital/aiologger/branch/master/graph/badge.svg)](https://codecov.io/gh/b2wdigital/aiologger)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


# About the Project

The built-in python logger is I/O blocking. This means that using the built-in
`logging` module will interfere with your asynchronous application performance.
`aiologger` aims to be the standard Asynchronous non-blocking logging for
python and asyncio.


# Documentation

The project documentation can be found here: https://b2wdigital.github.io/aiologger
